==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="146"/>
        <source>FFmpeg Plugin</source>
        <translation>FFmpeg 플러그인</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="152"/>
        <source>FFmpeg Formats</source>
        <translation>FFmpeg 형식</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="347"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>FFmpeg 오디오 플러그인 정보</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="348"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Qmmp FFmpeg 오디오 플러그인</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="349"/>
        <source>Compiled against:</source>
        <translation>컴파일 대상:</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="362"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>작성자: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>FFmpeg 플러그인 설정</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>형식</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows 미디어 오디오</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation>Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>True Audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG 오디오 레이어 3)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation>MPEG-4 AAC/ALAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>단축</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation>AC3/EAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation>DTS/DTS-코어</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation>Matroska Audio (Dolby TrueHD 무손실)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation>VQF</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="145"/>
        <source>Tom&apos;s lossless Audio Kompressor (TAK)</source>
        <translation>Tom&apos;s lossless Audio Kompressor (TAK)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>Direct Stream Digital (DSD)</source>
        <translation>Direct Stream Digital (DSD)</translation>
    </message>
</context>
</TS>

==> qmmp-1.7.4.tar.bz2: qmmp-1.7.4/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="144"/>
        <source>FFmpeg Plugin</source>
        <translation>FFmpeg 플러그인</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="150"/>
        <source>FFmpeg Formats</source>
        <translation>FFmpeg 형식</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="344"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>FFmpeg 오디오 플러그인 정보</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="345"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Qmmp FFmpeg 오디오 플러그인</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="346"/>
        <source>Compiled against:</source>
        <translation>컴파일 대상:</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="359"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>작성자: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFmpegSettingsDialog</name>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>FFmpeg 플러그인 설정</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>형식</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Windows 미디어 오디오</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation>Monkey&apos;s Audio (APE)</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>True Audio</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (MPEG 오디오 레이어 3)</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation>MPEG-4 AAC/ALAC</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>RealAudio 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>단축</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation>AC3/EAC</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation>DTS/DTS-코어</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation>Matroska Audio (Dolby TrueHD 무손실)</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation>VQF</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="145"/>
        <source>Tom&apos;s lossless Audio Kompressor (TAK)</source>
        <translation>Tom&apos;s lossless Audio Kompressor (TAK)</translation>
    </message>
    <message>
        <location filename="../ffmpegsettingsdialog.ui" line="152"/>
        <source>Direct Stream Digital (DSD)</source>
        <translation>Direct Stream Digital (DSD)</translation>
    </message>
</context>
</TS>
